==> igniteui-react-16.16.2.tgz: package/esm2015/lib/Form.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
import { FormDataEventArgs } from "./FormDataEventArgs";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
export let Form = /*@__PURE__*/ (() => {
    class Form extends BaseElement {
        constructor() {
            super(...arguments);
            this.c = new WCNativeHelper();
            this.h = null;
            this.submit = null;
            this.reset = null;
        }
        get d() {
            return this.c;
        }
        get nativeElement() {
            return this.h;
        }
        set nativeElement(a) {
            this.h = a;
            this.c.d = this.h;
        }
        get e() {
            let ret_ = this.d.c("novalidate");
            return ret_;
        }
        set e(a) {
            let value_ = a;
            this.d.i("novalidate", value_);
        }
        submitChanged() {
            if (this.submit != null) {
                this.d.g("submit", (a) => this.submit(this, FormDataEventArgs.b(a)));
            }
            else {
                this.d.h("submit");
            }
        }
        resetChanged() {
            if (this.reset != null) {
                this.d.g("reset", (a) => this.reset(this, VoidEventArgs.b(a)));
            }
            else {
                this.d.h("reset");
            }
        }
        f() {
            return (this.nativeElement.performSubmit());
        }
        j() {
            this.nativeElement.performReset();
        }
        g() {
            return (this.nativeElement.reportValidity());
        }
    }
    Form.$t = /*@__PURE__*/ markType(Form, 'Form', BaseElement.$);
    return Form;
})();

==> igniteui-react-18.5.1.tgz: package/esm2015/lib/Form.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
import { FormDataEventArgs } from "./FormDataEventArgs";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
export let Form = /*@__PURE__*/ (() => {
    class Form extends BaseElement {
        constructor() {
            super(...arguments);
            this.c = new WCNativeHelper();
            this.h = null;
            this.submit = null;
            this.reset = null;
        }
        get d() {
            return this.c;
        }
        get nativeElement() {
            return this.h;
        }
        set nativeElement(a) {
            this.h = a;
            this.c.o = this.h;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get e() {
            let ret_ = this.d.n("novalidate");
            return ret_;
        }
        set e(a) {
            let value_ = a;
            this.d.v("novalidate", value_);
        }
        submitChanged() {
            if (this.submit != null) {
                this.d.r("submit", (a) => this.submit(this, FormDataEventArgs.b(a)));
            }
            else {
                this.d.u("submit");
            }
        }
        resetChanged() {
            if (this.reset != null) {
                this.d.r("reset", (a) => this.reset(this, VoidEventArgs.b(a)));
            }
            else {
                this.d.u("reset");
            }
        }
        f() {
            return (this.nativeElement.submit());
        }
        j() {
            this.nativeElement.reset();
        }
        g() {
            return (this.nativeElement.reportValidity());
        }
    }
    Form.$t = /*@__PURE__*/ markType(Form, 'Form', BaseElement.$);
    return Form;
})();
